@@ -77,7 +77,8 @@ Z <- as.numeric(residuals(fit, standardize = TRUE))
 stopifnot(all.equal(Z, fit@fit$z, check.attributes = FALSE),
           all.equal(Z, as.numeric(resi/sig.)))
 qq_plot(Z, FUN = function(p) sqrt((nu-2)/nu) * qt(p, df = nu),
-        main = substitute("Q-Q plot of ("*Z[t]*") against a standardized"~t[nu.], list(nu. = nu)))
+        main = substitute("Q-Q plot of ("*Z[t]*") against a standardized"~italic(t)[nu.],
+                          list(nu. = round(nu, 2))))
 
 ## -----------------------------------------------------------------------------
 ## VaR confidence level we consider here
@@ -111,7 +112,7 @@ btest$cc.Decision # test decision
 fspec <- getspec(fit) # specification of the fitted process
 setfixed(fspec) <- as.list(coef(fit)) # set the parameters to the fitted ones
 m <- ceiling(n / 10) # number of steps to forecast (roll/iterate m-1 times forward with frequency 1)
-pred <- ugarchforecast(fspec, data = X, n.ahead = 1, n.roll = m-1, out.sample = m) # predict from the fitted process
+pred <- ugarchforecast(fspec, data = X, n.ahead = 1, n.roll = m-1, out.sample = m-1) # predict from the fitted process
 
 ## Extract the resulting series
 mu.predict <- fitted(pred) # extract predicted X_t (= conditional mean mu_t; note: E[Z] = 0)
